==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/block/block_entity/CacophoniumBlockEntity.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.block.block_entity;

import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2398;
import net.minecraft.class_2487;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import vazkii.botania.common.item.CacophoniumItem;

public class CacophoniumBlockEntity extends BotaniaBlockEntity {
	private static final String TAG_STACK = "stack";

	public class_1799 stack = class_1799.field_8037;

	public CacophoniumBlockEntity(class_2338 pos, class_2680 state) {
		super(BotaniaBlockEntities.CACOPHONIUM, pos, state);
	}

	public void annoyDirewolf() {
		CacophoniumItem.playSound(field_11863, stack, field_11867.method_10263(), field_11867.method_10264(), field_11867.method_10260(), class_3419.field_15245, 1F);
		if (!field_11863.field_9236) {
			float noteColor = field_11863.field_9229.method_43048(25) / 24.0F;
			((class_3218) field_11863).method_14199(class_2398.field_11224, field_11867.method_10263() + 0.5, field_11867.method_10264() + 1.2, field_11867.method_10260() + 0.5, 0, noteColor, 0, 0, 1);
		}
	}

	@Override
	public void writePacketNBT(class_2487 cmp) {
		super.writePacketNBT(cmp);

		class_2487 cmp1 = new class_2487();
		if (!stack.method_7960()) {
			cmp1 = stack.method_7953(cmp1);
		}
		cmp.method_10566(TAG_STACK, cmp1);
	}

	@Override
	public void readPacketNBT(class_2487 cmp) {
		super.readPacketNBT(cmp);

		class_2487 cmp1 = cmp.method_10562(TAG_STACK);
		stack = class_1799.method_7915(cmp1);
	}

}

==> Botania-1.20.1-451-FABRIC-20251214.151426-36-sources.jar: vazkii/botania/common/block/block_entity/CacophoniumBlockEntity.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.block.block_entity;

import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2398;
import net.minecraft.class_2487;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_5712;
import vazkii.botania.common.item.CacophoniumItem;

public class CacophoniumBlockEntity extends BotaniaBlockEntity {
	private static final String TAG_STACK = "stack";

	public class_1799 stack = class_1799.field_8037;

	public CacophoniumBlockEntity(class_2338 pos, class_2680 state) {
		super(BotaniaBlockEntities.CACOPHONIUM, pos, state);
	}

	public void annoyDirewolf() {
		CacophoniumItem.playSound(field_11863, stack, field_11867.method_10263(), field_11867.method_10264(), field_11867.method_10260(), class_3419.field_15245, 1F);
		if (!field_11863.field_9236) {
			float noteColor = field_11863.field_9229.method_43048(25) / 24.0F;
			((class_3218) field_11863).method_14199(class_2398.field_11224, field_11867.method_10263() + 0.5, field_11867.method_10264() + 1.2, field_11867.method_10260() + 0.5, 0, noteColor, 0, 0, 1);
			field_11863.method_33596(null, class_5712.field_38425, method_11016());
		}
	}

	@Override
	public void writePacketNBT(class_2487 cmp) {
		super.writePacketNBT(cmp);

		class_2487 cmp1 = new class_2487();
		if (!stack.method_7960()) {
			cmp1 = stack.method_7953(cmp1);
		}
		cmp.method_10566(TAG_STACK, cmp1);
	}

	@Override
	public void readPacketNBT(class_2487 cmp) {
		super.readPacketNBT(cmp);

		class_2487 cmp1 = cmp.method_10562(TAG_STACK);
		stack = class_1799.method_7915(cmp1);
	}

}
